{% extends "stampo.htm" %}
{% block title %}Aggiunta riassunto{% endblock %}
{% block content %}
<h1 class="display-4">Si è verificato un errore.</h1>
<p class="lead">Segue una spiegazione tecnica e professionale:</p>
<center><img src="https://http.cat/{{e}}" alt="Card image" width="70%"></center>
{% endblock %}